@@ -13,21 +13,21 @@ $VERSION = 0.01;
     'chmod' => '/sw/bin/chmod',
     'cp' => '/sw/bin/cp',
     'cpp' => '/usr/bin/cpp',
-    'date' => '/bin/date',
-    'dirname' => '/usr/bin/dirname',
-    'expr' => '/bin/expr',
-    'find' => '/sw/bin/find',
+    'date' => '/sw/bin/date',
+    'dirname' => '/sw/bin/dirname',
+    'expr' => '/sw/bin/expr',
+    'find' => '/usr/bin/find',
     'g++' => '/usr/bin/g++',
     'grep' => '/usr/bin/grep',
     'ln' => '/sw/bin/ln',
-    'make' => '/sw/bin/make',
+    'make' => '/usr/bin/make',
     'mkdir' => '/sw/bin/mkdir',
     'mv' => '/sw/bin/mv',
     'perl' => '/usr/bin/perl',
-    'rm' => '/bin/rm',
-    'rsync' => '/usr/local/bin/rsync',
-    'ssh' => '/sw/bin/ssh',
-    'yapp' => '/usr/bin/yapp',
+    'rm' => '/sw/bin/rm',
+    'rsync' => '/usr/bin/rsync',
+    'ssh' => '/usr/bin/ssh',
+    'yapp' => '/usr/local/bin/yapp',
   },
 );
 
